package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`"``!````(!<``#0```"DI@``!Q``<#0`(``+
M`"@`'P`>``8````T````-````#0```!@`0``8`$```0````$`````P```)0!
M``"4`0``E`$```T````-````!`````$````#``!PJ`$``*@!``"H`0``&```
M`!@````$````"````````'#``0``P`$``,`!```8````&`````0````$````
M`0```````````````````/2;``#TFP``!0```````0`!````^)\``/B?`0#X
MGP$`T`$``/@1```&```````!``(````<`@``'`(``!P"```X`0``.`$```0`
M```$````!````-@!``#8`0``V`$``$0```!$````!`````0```!1Y71D````
M```````````````````````'````$````%+E=&3XGP``^)\!`/B?`0`(````
M"`````0````!``````````````````````````````````````````0````O
M;&EB+VQD+G-O+C$`````````````(`(!`0`%`````````````````````/8!
M`+(`````````````````````,"`"``0````4`````P```$=.50!9@[<\K#2H
M+$[N.+!QQDS"^L%1O00````0`````0```$=.50```````P````(`````````
M`0```$P#```!````7`,```$```!L`P```0```'8#```,````X!,```T```#0
M7```&0```/B?`0`;````!````!H```#\GP$`'`````0````$````5`,```4`
M```H#0``!@```(@&```*````"04```L````0````-0``<)R=`0`5````````
M``,```!`H`$`$0```+@3```2````*````!,````(`````0``<`$````%``!P
M`@````8``'``````"@``<!L````1``!P:@```!(``'`>````$P``<"0````>
M````"````/O__V\!```(_O__;P@3``#___]O`P```/#__V\R$@``````````
M````````````````````````````````````````````````````````80``
M`&H```````````````T````L``````````````!"```````````````I````
M30````````!(````3@```"(`````````50```!H````#````+@````D````1
M````/@```#$``````````````%8````5````*```````````````(P```!T`
M```_```````````````6````6P`````````W`````````#4`````````9@``
M`!0````2````)@````````!G````&P````````!'````4P``````````````
M&0```$D````[````1@````````````````````````!1`````````"$`````
M`````````&$````G````*@```"\````7````*P```````````````@````H`
M``!!````9````!P````0````-@`````````D````(```````````````$P``
M`!@`````````0````!\```!#````)0```#(````\````````````````````
M`````````````````````&,``````````````&4`````````````````````
M````4````&(`````````#```````````````1`````0```!%````````````
M`````````````%P```!8``````````````````````````X````X````/0``
M```````S````2@```#`````>`````````"T`````````-````%T```!I````
M8````$\````Z````````````````````.0```````````````````%\```!,
M````````````````````#P`````````(``````````````!>````"P```$L`
M`````````````%D`````````5P````````````````````````!2````5```
M````````````````````````````6@```&@```````````````4`````````
M``````<```````````````````````````````8`````````````````````
M````````````````````````````````````X!,````````#``T`C@,``/18
M```(````$@`.`#<$``!H)```&````!(`#@`!`````0`````````3`/'_A00`
M``"@`0``````(``5`!X#`````````````!$```!(!```W"X``$@````2``X`
M*P0``%@_``",`0``$@`.`&,$``#(H0$``````!``&`!J!```0"<``"P````2
M``X`=P0``&PG```\````$@`.`!0$``"D,```-`L``!(`#@#R`P``A%0``/P!
M```2``X`@P0```"@`0``````$``5```#````70``!````!$`$0"0!````*`!
M```````0`!4`M`,``%PC```,`0``$@`.`!(````PH`$``````!$`%@!^`P``
M4%@``*0````2``X`(00``""@`0`$````$0`5`)<$``#PL0$``````!``&0`'
M!```J"<``(0&```2``X`_0,``(!6``#0`0``$@`.`)P$``#(H0$``````!``
M&0"H!```"",``%0````2``X`<0(``"`4``#X`@``$@`.`+`$```@%P``````
M`!(`#@#<`P``@"0``,`"```2``X`R@,``"0O``"``0``$@`.`!\#````````
M`````"$```"X!```+"X``+`````2``X`Q@0``"`4````````$``.`,T$``#(
MH0$``````!``&0#I`P``U%,``+`````2``X`G@,``-@[``"``P``$@`.`+,"
M``"P7````````!(```#O`0``H%P````````2````1@(``)!<````````$@``
M`+`!``"`7````````!(```#U`@``<%P````````2````M@$``&!<````````
M$@```),"``!07````````!(````@`P`````````````1````/@(``$!<````
M````$@```+,``````````````"`````%`@``,%P````````2````J0(``"!<
M````````$@```*H````07````````!(```#-`````%P````````2````F0``
M````````````$@```,@"``#P6P```````!(```#<````X%L````````2````
M$P(``-!;````````$@```/,```#`6P```````!(```".````L%L````````2
M````]P$``*!;````````$@````0!``"06P```````!(```"`````@%L`````
M```2````P0(``'!;````````$@```-X!``!@6P```````!(```!M````````
M```````2````HP(``%!;````````$@```"@"``!`6P```````!(````0`0``
M,%L````````2````&P$``"!;````````$@```#`!```06P```````!(```#*
M`0```%L````````2````9`(``/!:````````$@```-8"``#@6@```````!(`
M``!>````T%H````````2````70(``,!:````````$@```(X"``"P6@``````
M`!(````\`0`````````````B````2P$``*!:````````$@```&<!``"06@``
M`````!(````/`P``@%H````````2````6P$``'!:````````$@```!H"``!@
M6@```````!(```#6`0``4%H````````2````*`,``$!:````````$@```%,`
M```P6@```````!(```!N`0``(%H````````2````=@(``!!:````````$@``
M`'P!`````````````!$```!%`````%H````````2````+P(``/!9````````
M$@```(D!`````````````!$```#N`@``X%D````````2````W0(``-!9````
M````$@```#L```#`60```````!(````L````L%D````````2````G0(``*!9
M````````$@```!P``````````````!(````Z`P`````````````1````SP(`
M`)!9````````$@```$\"``"`60```````!(```!`````<%D````````2````
M-@(``&!9````````$@```!<#`````````````!$```!:!```4%D````````2
M````E`$`````````````(````-$!``!`60```````!(```!_`@``````````
M```B````(0(``#!9````````$@```%8"```@60```````!(`````7T193D%-
M24-?3$E.2TE.1P!?7U),1%]-05``8F]O=%]$>6YA3&]A9&5R`'!E<FQ?8V]N
M<W1R=6-T`'!E<FQ?9G)E90!P97)L7V1E<W1R=6-T`'!E<FQ?86QL;V,`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`
M<&5R;%]P87)S90!097)L7V%T9F]R:U]L;V-K`'!E<FQ?<G5N`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S=E]S971P=FX`4&5R;%]C<F]A:U]M
M96UO<GE?=W)A<`!097)L7VYE=UA37V9L86=S`%!E<FQ?;6=?<V5T`%!E<FQ?
M;F5W6%,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]G971?<W8`7U]G;6]N
M7W-T87)T7U\`4&5R;%]G=E]F971C:'!V`%!E<FQ?<V%F97-Y<VUA;&QO8P!0
M97)L7W-V7W-E='!V`%!,7V1O7W5N9'5M<`!03%]T:')?:V5Y`%])5$U?9&5R
M96=I<W1E<E1-0VQO;F5486)L90!C;&]S90!P=&AR96%D7V=E='-P96-I9FEC
M`&]P96XV-`!R96%D`&QS965K-C0`7U]E<G)N;U]L;V-A=&EO;@!O<&5N9&ER
M`%]?<W1R;F-P>5]C:&L`7U]F<')I;G1F7V-H:P!A8V-E<W,`9V5T<&ED`'-T
M<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!C;&]S961I<@!S
M=')D=7``<W1R<W1R`'-T<F-H<@!?7VQI8F-?<W1A<G1?;6%I;@!R96%D;&EN
M:P!?7V-X85]F:6YA;&EZ90!E>&ET`%]?>'-T870V-`!R;61I<@!M:V1I<@!R
M96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UC:'(`<W1R=&]K`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`7U]L>'-T870V-`!?24]?
M<W1D:6Y?=7-E9`!R96%L;&]C`'-T9&5R<@!?7V5N=FER;VX`7U]R96=I<W1E
M<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,R`&QI
M8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0N<V\N,0!?7VQI8F-?8W-U7VEN
M:70`7U]L:6)C7V-S=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P
M<F]G`'-H85]I;FET`'-H85]U<&1A=&4`<VAA7V9I;F%L`'!A<E]I;FET7V5N
M=@!P87)?;6MT;7!D:7(`;7E?<&%R7W!L`'!A<E]C;&5A;G5P`'!A<E]C=7)R
M96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`7V5D871A`'!A
M<E]B87-E;F%M90!P87)?9&ER;F%M90!?7V1A=&%?<W1A<G0`7V9D871A`%]E
M;F0`7U]B<W-?<W1A<G0`>'-?:6YI=`!?7W-T87)T`'!A<E]E;G9?8VQE86X`
M7V9T97AT`%]F8G-S`$=,24)#7S(N-`!'3$E"0U\R+C(`1TQ)0D-?,BXP`$=,
M24)#7S(N,RXT`$=,24)#7S(N,RXR`````````0`!``$``0`"``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``$``0`!
M``$``0`)``(``@`$``,`!``#``(``@````D``P`````````"`````@``````
M"0```````@`$`````@`"``````````@``@`"`````@`"```````"``(````"
M``@`!P```````@```````@````(`!@```````@````4``@`"``(``@`"``(`
M```$``,``@`"`````0`!`'8#```0````(````!1I:0T```4`TP0````````!
M``(`7`,``!`````P````$FEI#0``"`#=!```$````!!I:0T```0`YP0`````
M```!``4`;`,``!``````````=!EI"0``"0#Q!```$````'(9:0D```<`_00`
M`!`````4:6D-```&`-,$```0````$FEI#0```P#=!```$````!!I:0T```(`
MYP0``````````````````/B?`0`#````_)\!``,````@H`$``P```,2A`0`#
M`````@`</%`,G"<AX)D#X/^])Q``O*\<`+^O$(&"CP0`0!``````$(&9CPGX
M(`,`````'`"_CP@`X`,@`+TG``````(`'#P0#)PG(>"9`[#_O2<$@9F/-`"P
MKQ@`O*],`+^O2`"UKT0`M*]``+.O/`"RKS@`L:]D@9"/)`"EKR0`I2<@`*:O
M(`"F)U``I*]0`*0G```"CBP`HJ\)^"`#`````!@`O(_@@(:/5("9C[2`A(\;
M$1$$)2C``!@`O(\\@8*/``!"D&8`0!`P@9F/2(&1CY"`F8\)^"`#```DCA@`
MO(]F`T.0```DCI"`F8\"`&,T"?@@`V8#0Z``0`,\4`"QCV8#19`8`+R/!``D
M)@$`I30K&(,`9@-%H'P`8!`#`#$F((&9CPGX(`.`(`0`)`"HCR4X0``8`+R/
M4`"BCP```XU8@(2/*("&CP``XZPD@(./``"%C`(`1"CHL<>L,&!C)`@`Y:P$
M`..L)("#CS1@8R1I`(`4#`#CK(`0`@`$``,E$`#D)"%``@$``&6,!`!C)`0`
MA"3\_V@4_/^%K`P`0B0H@)*/(1#B`"2`A8\E,"`"R("9CP``0*P0`*"O7"*E
M)`GX(`/LL42.&`"\CS8`0!`EB$``0(&9CR@`M"<)^"`#[+%$CB4H@`(8`+R/
M)("3CR2`A(^0&',F)<A@`JP`$03(780D+@!`$!@`O(]4@9F/"?@@`^RQ1(X8
M`+R/U("9CPGX(`,`````+`"CCP```HX[`&(4&`"\CTP`OX\E$"`"2`"UCT0`
MM(]``+.//`"RCS@`L8\T`+"/"`#@`U``O2<)^"`#`````!@`O(\E($``*(""
MCRT`@!#LL42L6(&9CTB!D8\)^"`#`````!@`O(^0@)F/"?@@`P``)(X8`+R/
MB_\`$!T'0*"L@)F/"?@@`^RQ1(X8`+R/QO\`$"6(0``H@)6/Y+&DC@4`@!!<
M@)F/*0H1!`````#,_P`0&`"\CR2`A(\E*(`")<A@`G``$01H780D&`"\CR4@
M0`##_T`0Y+&BKO+_`!!<@)F/O("9CPGX(`,`````H?\`$!```B10@9F/"?@@
M`P`````,@9F/"?@@`P$`!"0``````````"4`X`,!`!$$``````(`'#P$"9PG
M(>"?`R7X```8@(2/``"ECP0`IB?X_P$D).BA`^#_O2<<@(>/(("(CQ``J*\4
M`**O&`"]K_R`F8\)^"`#`````/__`!````````````(`'#RP")PG(>"9`RB`
MA(]@@(*/-*"$)`4`1!"`@9F/`P`@$P`````(`"`#``````@`X`,``````@`<
M/'@(G"<AX)D#*("$CV"`A8\TH(0D(RBD`(,0!0#"+P4`(2BB`$,H!0`%`*`0
MH("9CP,`(!,`````"``@`P`````(`.`#``````(`'#PL")PG(>"9`^#_O2<8
M`+"O*("0CQ``O*\<`+^OT*$"D@T`0!2(@8*/!0!`$&2`@H^(@9F/"?@@`P``
M1(P0`+R/)("9CX`7.2?+_Q$$``````$``B30H0*B'`"_CQ@`L(\(`.`#(`"]
M)P(`'#S`!YPG(>"9`R2`F8^X%SDGS/\`$````````````@`</*`'G"<AX)D#
MR/^])Q``O*\T`+^O,`"VKRP`M:\H`+2O)`"SKR``LJ\<`+&O/0"`$!@`L*^8
M@(*/``!5C#D`H!(]``,D``""@"6@@``EF*``0`!`$"60@``$`$,0``````$`
M0H+\_T`4`0!2)B.05`(``+".$```$CT`%B0EB*`"G("9CR4@``(E,$`""?@@
M`R4H@`(A&!("!`!`%!``O(\``&*`#P!6$``````$`#".\_\`%@0`,28T`+^/
M)1```C``MH\L`+6/*`"TCR0`LX\@`+*/'`"QCQ@`L(\(`.`#.`"])R.(-0(!
M`%(F@X@1`"&`$@(``'&N-`"_CR40``(P`+:/+`"UCR@`M(\D`+./(`"RCQP`
ML8\8`+"/"`#@`S@`O2<T`+^/)8```#``MH\L`+6/)1```B@`M(\D`+./(`"R
MCQP`L8\8`+"/"`#@`S@`O2?&_P`0)9````(`'#Q`!IPG(>"9`Q#_O2?4`+*O
M&`"\K^P`OZ_H`+>OY`"VK^``M:_<`+2OV`"SK]``L:_,`+"O9(&2CP``0H[$
M`**O!`"`$````````(*`#P!`%"6`@`#$`*./``!"CFT`8A3L`+^/Z`"WC^0`
MMH_@`+6/W`"TC]@`LX_4`+*/T`"QC\P`L(\(`.`#\`"])X"`F8\)^"`#````
M`!@`O(_M_T`0)8A``"2`DX\@`+4G)("4CP1=<R;P&90FJ("9CPGX(`,E("`"
M/0!`$!@`O(\3`$.0TO]C)`0`8!03`%8D`0##DO;_8!"H@)F/$P!"D-+_0B0[
M`$`0`(&9CPGX(`,E(``")2#``A@`O(\`@9F/"?@@`R6X0``8`+R/(1#B`AB!
MF8\)^"`#`@!$)/__!B08`+R/`0`%)"4@0``4`+:O)3A@`A``L*]\@)F/"?@@
M`R6X0``#``0D&`"\CR4PH`*4@)F/"?@@`R4HX`+__P,D!@!#$!@`O(\X`**/
M`$`#)`#P0C`@`$,0)<B``D2!F8\)^"`#)2#@`A@`O(]P@9F/"?@@`R4@X`(8
M`+R/J("9CPGX(`,E("`"Q?]`%!@`O(^$@)F/"?@@`R4@(`(8`+R/7(&9CPGX
M(`,E(``"GO\`$!@`O(\!`,*2TO]"),/_0!0``````@#"DK#_0!``````OO\`
M$`````!]_Q$$)2#@`N+_`!`8`+R/4(&9CPGX(`,``````@`</!P$G"<AX)D#
M,/^])XR`F8\8`*8GR`"QKQ``O*_$`+"O)8"``,P`OZ\#``0D9(&1CR4H``(`
M`"*.O`"BKPGX(`,`````#P!`%!``O(\P`*./`$`$)`#P8S`#`&00`*`$-`D`
M9!0`````P("9CP(`!20)^"`#)2```A``O(\"```0`0!"+"40``"\`*2/```C
MC@4`@Q3,`+^/R`"QC\0`L(\(`.`#T`"])U"!F8\)^"`#``````(`'#QD`YPG
M(>"9`]C_O2<`@9F/$`"\KQP`L*\E@(``)`"_KPGX(`,@`+&O+P`#)/__1B0A
M,`8"*Q`&`@4`0!00`+R/,0``$``````Q``82````````PH#\_T,0___&)`$`
MQB0K$`8"*`!`$"\``R3__\8D)P`&$@```````,*`_/]#%/__QB0!`,8D!```
M$"\``R0``,*`!0!#%`````#__\8D*Q`&`OK_0!0`````(S#0``(`PB0!$$(L
M#0!`$"B`D8\`$`<DS("9CP$`QB0E*``""?@@`^"A)";@H2(F)`"_CR``L8\<
M`+"/"`#@`R@`O2<D`+^/)1```"``L8\<`+"/"`#@`R@`O2?D_P86+P`#)```
M`X(O``(D"`!B$&R!F8\D@(2/)`"_CR``L8\<`+"/$%V$)`@`(`,H`+TG)("$
MCR0`OX\@`+&/'`"PCPQ=A"0(`"`#*`"])P(`'#P(`IPG(>"9`\#OO2<X@9F/
M_P\&)"P0LJ\0`+RO-!"TKR6@H``P$+.O'`"S)R00L*\E@(``/!"_KR4H8`(X
M$+6O*!"QKV2!DH\D@(2/``!"CA1=A"0<$**O"?@@`P`````Z`$`8$`"\C___
M421(@82/(!"C)R$8<0#\[V.`(`!@%```E8PF`"`2V("9CR\`!20E,"`""?@@
M`R4@8`(@`$`0$`"\CY"`F8\)^"`#)2"@`B4X(`(0`+R/)3!@`B4H``*P@)F/
M"?@@`R4@0``0`+R/'!"CCP``0HX?`&(4/!"_CS@0M8\T$+2/,!"SCRP0LH\H
M$+&/)!"PCP@`X`-`$+TGV("9CR6(0``O``4D)3`@`@GX(`,E(&`"XO]`%!``
MO(^0@)F/"?@@`R4@H`(E,(`"$`"\CR4H``(T@9F/"?@@`R4@0`#B_P`0$`"\
MCTB!@H_S_P`0``!5C%"!F8\)^"`#``````(`'#R@`)PG(>"9`[C_O2<]``(D
M*`"QKS``LZ\EF(``)`"PKR6`H``0`+RO1`"_KT``MZ\\`+:O.`"UKS0`M*\L
M`+*O9(&1CP``HX```"6.'`"EKP(`8A0`@9F/`0`0)@GX(`,E(``"&`"E)Q``
MO(\E(&`")("9CY`8.2<@_A$$):!``!``O(]7`$`0)9!```"!F8\)^"`#)2!`
M`"L05`!!`$`0$`"\CQ@`LH^8@)6/@+`2````98(]``(D!@"@%"488`)Y```0
M)1@```$`98`#`*`0`0!C)/S_HA0`````(QAS````LHX"`(0F&(&9CR$@@P`)
M^"`#(9!6`A``O(\;`$`0``!"KA@`I(\!`&4F``"BCCT`!B0``&."@"`$`"$0
M1````$*,!P!@%```0Z!<```0)2!`````HX`!`*4D)0!@$```0Z`E($``^O]F
M%`$`0B0]``,D``"#H````X(!`$(D`0`0)OS_8!3__T.@'`"CCP``(HY1`&(4
M1`"_CT``MX\\`+:/.`"UCS0`M(\P`+./+`"RCR@`L8\D`+"/"`#@`T@`O2<`
M``*"`0!2)@$`$";N_T`0__]"H@```H(!`%(F`0`0)O?_0!3__T*BY_\`$```
M```"`(,D)2!``-S_`!`E$&``F("5CP``MXX``.*.+P!`$"40X`(ED```!`!#
MC"4@0`($`$(D_/]@%`$`4B8#`(0D@"`$`"B`@H_@L4.,%@!@%!R!F8\8@9F/
M`0`#)`GX(`/@L4.L$`"\C\O_0!`E($``=(&9CX"P$@`E*.`""?@@`R4PP`(0
M`+R/)2!`````HJX!`$(F@!`"`"$@@@```("LCO\`$!@`LJ\E*(``"?@@`R4@
MX`(0`+R/)2!``+;_0!```**N\O\`$("P$@"K_P`0`0!")([_`!```+*."``$
M)-C_`!`ED```4(&9CPGX(`,``````@`</-3]G"<AX)D#V/^])Y"`F8\@`+"O
M)`"_KQ@`O*](@9"/"?@@`P``!(X8`+R/D("9CPGX(`,```2.&`"\CR4@0``L
M@(>/)("%CV"!AH_L@)F/Y)OG)`GX(`,D7:4D&`"\CY"`F8\)^"`#```$CA@`
MO(\E($``%`"@KR2`AX\D@(6/Q("9CRQ@YR0P@(:/0%VE)`GX(`,0`*>O)`"_
MCR``L(\(`.`#*`"])P(`'#PH_9PG(>"9`^#_O2=(@8*/D("9CQP`OZ\0`+RO
M"?@@`P``1(P0`+R/)2!``!P`OX\@`+TG+("'CR2`A8]@@8:/[("9C^2;YR0(
M`"`#)%VE)`(`'#S4_)PG(>"9`[C?O2<D@9F//""QKT0@OZ\8`+RO0""RKS`0
MLB<X(+"O9(&1CP``(HXT(**O"?@@`P`````L`*0G&`"\CP$0!B00`**O`0`%
M)"0`I*\D@(*/)("'CWR`F8]D74(D6%WG)`GX(`,4`**O`!`&)!@`O(\E*$`"
M.(&9CPGX(`,D`*2/&@!`!!@`O(\8@9F/`0!$)`GX(`,E@$``&`"\CPD`0!`E
M($``:(&9CR4P``()^"`#)2A``B&`4``8`+R/)2!``````*(T(*./```BC@D`
M8A1$(+^/)1"``$`@LH\\(+&/.""PCP@`X`-((+TG]?\`$"4@``!0@9F/"?@@
M`P`````"`!P\R/N<)R'@F0,T@)F/N/\`$``````"`!P\L/N<)R'@F0/X[KTG
M)("9C_@0MJ^0&#DG(`"\KP01OZ_L$+.O)9B@`.00L:\EB(``X!"PKS0`I2<`
M$;ZO_!"WK_00M:_P$+2OZ!"RKV2!EH\D@(2/``#"CFA=A"3<$**OZOP1!```
M```O``4D(`"\CR4@(`((@9F/"?@@`R6`0``8`$`0(`"\CR2`A(\E*"`")("9
MCY`?.2><_A$$=%V$)"40(`(@`+R/W!"DCP``PXY_`(,4!!&_CP`1OH_\$+>/
M^!"VC_00M8_P$+2/[!"SC^@0LH_D$+&/X!"PCP@`X`,($;TG`(&9CR2`DH\)
M^"`#)2`@`B4@8`(@`+R/A%U%)KB`F8\)^"`#)9A``"``O(_=_T`0);A``"2`
M@H\D@)2/)("5CPQ=0B0L`**O``#B@C\`0!`0790F!@``$HR!F8\E*.`""?@@
M`R4@``(N`$`0(`"\CP"!F8\)^"`#)2#@`B\`!"0E&$``(1#B`O__0H`*`$04
M(`"\CR\`!20E(&``__]C)"$@Y`(A$.,"__^`H/__0H#Z_T40)2!@``$`8B8A
M&$,``!!C*+?_8!!\@)F/W`"^)XA=IR88`+&O`!`&)!0`M*\!``4D$`"WKPGX
M(`,E(,`#.`"F)R``O(\#``0DE("9CPGX(`,E*,`#!@!`%"``O(]0`**/`(`#
M-`#P0C`:`$,0P("9C[B`F8^$744F"?@@`R4@```@`+R/FO]`$"6X0````.*"
MP_]`%``````%```2`````````I+2_T(D!`!`$``````L`+>/T_\`$`$``R0!
M``*2[/]`$+B`F8\L`+>/S?\`$`$``R0!``4D"?@@`R4@P`/C_T`4(`"\CR2`
MA(\E*,`#)("9CY`?.2<>_A$$=%V$)"``O(]L@9F/"?@@`R4@P`-__P`0(`"\
MCU"!F8\)^"`#````````@X`'`&`0)1"```$`A"0O`&,X"A"#````@X#\_V`4
M`0"$)`@`X`,``````@`</,3XG"<AX)D#!P"`$````````(*`!`!`$"2`F8_,
M'#DG3OT`$``````D@(2/;(&9CP@`(`,,780D`@`</(CXG"<AX)D#D/^])RR`
M@H\@`*,G5`"SK\";0B00`+RO;`"_KR``2"1H`+ZO9`"WKV``MJ]<`+6O6`"T
MKU``LJ],`+&O2`"PKV2!DX\``&2.1`"DKP``1XP0`$(D$`!C)/#_9ZST_T:,
M^/]%C/S_1(ST_V:L^/]EK/;_2!3\_V2L)("4CQP`L2<D@)"/``!"E)B`DH^0
M790FD!@0)@``8J0E*"`")<@``@[\$00E((`"$@!`$!``O(\<`*./``!"CH`8
M`P`A$$,`!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"_?L1
M!"4@@`+P_T`4$`"\CR2`E(^8@)*/G%V4)B4H(`(ER``"]/L1!"4@@`(2`$`0
M$`"\CQP`HX\``$*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0`
M`$.L)2@@`B7(``+C^Q$$)2"``O#_0!00`+R/)("4CYB`DH^D790F)2@@`B7(
M``+:^Q$$)2"``A(`0!`0`+R/'`"CCP``0HZ`&`,`(1!#``0`0XST_V`0``!#
MK`@`0XP$`$(D_?]@%```0ZPE*"`")<@``LG[$00E((`"\/]`%!``O(\D@)2/
MF("2C[!=E"8E*"`")<@``L#[$00E((`"$@!`$!``O(\<`*./``!"CH`8`P`A
M$$,`!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"K_L1!"4@
M@`+P_T`4$`"\CR2`E(^8@)*/N%V5)B4H(`(ER``"IOL1!"4@H`(2`$`0$`"\
MCQP`HX\``$*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0``$.L
M)2@@`B7(``*5^Q$$)2"@`O#_0!00`+R/)("5CYB`DH_(7;4F)2@@`B7(``*,
M^Q$$)2"@`A(`0!`0`+R/'`"CCP``0HZ`&`,`(1!#``0`0XST_V`0``!#K`@`
M0XP$`$(D_?]@%```0ZPE*"`")<@``GO[$00E(*`"\/]`%!``O(\D@)6/F("2
MCVA=MB8E*"`")<@``G+[$00E(,`"$@!`$!``O(\<`*./``!"CH`8`P`A$$,`
M!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"8?L1!"4@P`+P
M_T`4$`"\CR2`EX^8@)*/U%WV)B4H(`(ER``"6/L1!"4@P`(2`$`0$`"\CQP`
MHX\``$*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0``$.L)2@@
M`B7(``)'^Q$$)2#``O#_0!00`+R/)("6CYB`DH_@7=XF)2@@`B7(``(^^Q$$
M)2#``Q(`0!`0`+R/'`"CCP``0HZ`&`,`(1!#``0`0XST_V`0``!#K`@`0XP$
M`$(D_?]@%```0ZPE*"`")<@``BW[$00E(,`#\/]`%!``O(\D@)Z/F("2C^Q=
MWB<E*"`")<@``B3[$00E(,`#$@!`$!``O(\<`*./``!"CH`8`P`A$$,`!`!#
MC/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"$_L1!"4@P`/P_T`4
M$`"\CR2`GH^8@)*/=%W>)R4H(`(ER``""OL1!"4@P`,2`$`0$`"\CQP`HX\`
M`$*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0``$.L)2@@`B7(
M``+Y^A$$)2#``_#_0!00`+R/)("$CR4H(`(ER``"\OH1!/A=A"00`+R/-0!`
M$"4H0``D@)*/D!]2)B7(0`*J_!$$X%W$)A``O(\D@(2/)2@@`B7(``+D^A$$
M#%Z$)!``O(\&`$`0)2A``"2`A(\ER$`"G?P1!"!>A"00`+R/)("$CR4H(`(E
MR``"U_H1!"Q>A"00`+R/'0!`$"4H0``ER$`"D?P1!&A=I"80`+R/)("%C[A=
MA"8ER$`"B_P1!%Q>I21$`*./``!BCBL`8A00`+R/;`"_CV@`OH]D`+>/8`"V
MCUP`M8]8`+2/5`"SCU``LH],`+&/2`"PCP@`X`-P`+TG)("2C]#_`!"0'U(F
M)("$CR4H(`(ER``"L_H1!#Q>A"0'`$`0$`"\C]1=Y"8ER$`";?P1!"4H0`#<
M_P`0$`"\CR2`A8\*``8DG("9CS$`I"<)^"`#4%ZE)-3_0!00`+R/.P"E)R7(
M0`)?_!$$U%WD)L[_`!`0`+R/4(&9CPGX(`,``````@`</`3RG"<AX)D#T/^]
M)___`R0H`+&O)`"PKQ``O*\L`+^O9(&0CRB`D8\```2.$*`BCAP`I*\)`$,0
M)("$CQP`I(\```..%@"#%"P`OX\H`+&/)`"PCP@`X`,P`+TG&`"E)R2`F8^0
M&#DG??H1!-1=A"0(`$`0$`"\CP``0H`%`$`0`````#``0C@K$`(`Z_\`$!"@
M(JXE$```Z/\`$!"@(JY0@9F/"?@@`P`````"`!P\5/&<)R'@F0/@_[TG3(&9
MCQ``O*\<`+^O"?@@`P`````0`+R/?(&9CPGX(`,E($```@!`$!P`OX\``$*,
M"`#@`R``O2<"`!P\#/&<)R'@F0.X_[TG)("9CR@`I2<X`+*OD!@Y)R``O*\\
M`+.O-`"QKR6(@`!$`+^O0`"TKS``L*]D@9*/)("3CP``0HY@7F0F+`"BKT;Z
M$00`````!0!`$"``O(\E@$````!"@!``0!20@9F/+`"CCP``0HX^`&(48%YD
M)B4H(`(D@)F/1`"_CT``M(\\`+./D!\Y)S@`LH\T`+&/,`"PC_'[`!!(`+TG
M)2@@`@GX(`,E(``"#`!`$"``O(\L`*./``!"CBH`8A1$`+^/0`"TCSP`LX\X
M`+*/-`"QCS``L(\(`.`#2`"])P"!F8\)^"`#)2`@`B4@``(@`+R/`(&9CPGX
M(`,EH$``(`"\CR$0@@(8@9F/"?@@`P(`1"3__P8D(`"\CR6@0``!``4D&`"P
MKQ``L:\E((`")(""CR2`AX]\@)F/A%U")(A=YR0)^"`#%`"BKRP`HX\``$*.
M!`!B%"``O(]@7F0FQ?\`$"4H@`)0@9F/"?@@`P`````"`!P\C.^<)R'@F0,0
M@+TG)("'CU"!`S3__P(\Z'^^K]Q_M:\EJ(``V'^TK^1^123,?[&O['^_K^1_
MMZ_@?[:OU'^SK]!_LJ_(?["O</Z])V2!GH\(`*0G)("4CR@`O*\A&&0`)("$
MCP``QH^0&)0F(1!B`#``IZ]P7I$D4($#-`@`I"?P?D"L%']`K"7(@`(A&&0`
M]'Y1K&A=Y"3\?D"L(2AE`"2`@X\(`*<G@%YC).A^0ZPD@(./#%UC).Q^0ZQ,
M@0,T(1AG````9JPD@(./)%YC)`1_0ZPD@(./B%YC)`A_0ZPD@(./;%UC)`Q_
M0ZPD@(./D%YC)!!_0ZPD@(./E%YC)+GY$03X?D.L!`!`$"@`O(\``$.`F0%@
M%#B`F8],@9F/"?@@`P`````H`+R/?(&9CPGX(`,E($``60%`$"@`O(\``%",
M5P$`$O__$CP`@9F/"?@@`R4@``(H`+R/0"`"`!B!F8\)^"`#`0"$)````X(E
MB$``$0!@$"@`O(\D@(>/)9`@`J!>\R1\@)F/`0`0)O\`8S#__P8D$`"CKP$`
M!20E($`""?@@`R4X8`("`%(F```#@O3_8!0H`+R/__\3/"2`A(\(`*,G)("2
MCU"!`C0`?W8F(1!#`.1^<R8AL%8`4($"-"!>A"0A$$,`%!Q2)@0``!`AF%,`
M!`#$CFX`@!`$`-8F)<B``G?Y$00E*&`"*`"\C_C_0!`E@$````!"@/7_0!`E
MR$`"4/H1!"4@``+Q_T`0*`"\CVR!F8\)^"`#)2```B@`O(];`$`0)8!```"!
MF8\)^"`#)2```B4@(`(H`+R/`(&9CPGX(`,EL$``*`"\CR&PP@($!-8F&(&9
MCPGX(`,E(,`"__\&)"@`O(\ED$```0`%)!P`L:\E($`"$`"PKR2`DX\D@(*/
M)("'CWR`F8\077,FM%Y")*A>YR04`+.O"?@@`Q@`HJ_``04D*`"\C^2`F8\)
M^"`#)2!``O__`R0(`$,4*`"\C]R`F8\)^"`#`````!$``R0``$*,$0%#%"@`
MO(\(`*,GC("9C___$3Q0@0(T&'\F)B$00P`#``0D(3!&``GX(`,E*$`"*`"\
MCT(`0!`E@$``>(&"CP$`!20D@(:/)8@``*2`F8\``*>.``!$C/A>QB0)^"`#
M$`"RKR@`O(\(`*,G3($"-"$00P```$.,``#"C^D!8A0E$"`"D`&])^Q_OX_H
M?[Z/Y'^WC^!_MH_<?[6/V'^TC]1_LX_0?[*/S'^QC\A_L(\(`.`#\'^])P@`
MHR<D@)./4($"-/__$CPA$$,`%!QS)B$04@#H?E(FZ'Y0C%"!`C0A$$,`!```
M$"&04@`$`%".$0``$@0`4B8```*"#@!`$"7(8`+9^1$$)2```O?_0!`H`+R/
M;(&9CPGX(`,E(``"*`"\CXK_0!0E@$``!`!0CO'_`!8$`%(FA?\`$"6````(
M`*,G4($"-"$00P``0`,D(;A1`#!_XHX`\$(PN/]#%'B!@H\X?^..3(&9CPGX
M(`,T`*.O-`"CC[#_8A0H`+R/,'_BCL`!`R3_`4(PK/]#%'B!@H\8@9F/"?@@
M`R4@P`((`*0G*`"\CU"!`S3D?B4F(1AD`"7(@`(D@(2/(2AE`"6(0`#(^!$$
M3%^$)"@`O(](`4`0)2!``&R!F8\)^"`#``"VCB@`O(\E*$``/("9C[G[$00E
M(,`"*`"\CST!0!`EN$```(&9CPGX(`,E(.`");!```0`0BP0`$`4*`"\CR2`
MA8_\_\0FC(&9CR$@Y`()^"`#5%^E)`@`0!0H`+R/!``")#\!PA(AL/8"+P`"
M)/O_PX([`6(0`````"B`E8___P,D$*"BCB0!0Q`(`*,GG@!`$/B`F8\D@):/
M)(""C]1=Q"8D@(6/__\6)!$`%R20'UDD7%ZE)%/Z$00T`+FO*`"\CR2!F8\)
M^"`#`````/__!B0H`+R/`0`%)"4@(`(8`**O%`"SKQ``LJ\D@)2/)("'CWR`
MF8\L8)0F=%_G)`GX(`,<`+2O*`"\CR2`E8\7```0A%^U)MR`F8\)^"`#````
M````0HP7`%<4*`"\CR2!F8\)^"`#`0`0)O__!B0H`+R/`0`%)"``M*\E.*`"
M'`"PKR4@(`(8`**O%`"SKWR`F8\)^"`#$`"RKR@`O(_D@)F/P`$%)`GX(`,E
M("`"Y?]6$"@`O(]P@9F/"?@@`R4@0`(E*"`",`"BCS0`N8\)^"`#:%U$)"@`
MO(\X@)F/^OT1!"4@(`(S_P`0*`"\C___$CP(`*,G4($"-"4@(`(A$$,`]'Y1
M)N1^4B8AB%$`4($"-"$00P`%```0(9!2``0`)(X4`(`0&(&9CP0`,28ER(`"
M0/@1!"4H0`+X_T`0*`"\CP``0X#U_V`0;(&9CPGX(`,E($``*`"\CX_^0!0E
M@$``!``DCO'_@!0$`#$F_/\Q)AB!F8\)^"`##0`$)%,``R0H`+R/)8A``"2`
MD(^._@`0>%X0)GB!@X\!``4D)("&CR6(``"D@)F/``"GC@``9(R\7L8D%`"B
MKPGX(`,0`+*O_/X`$"@`O(\E($``OOT1!#``HJ\(`*,G3($"-"@`O(\A$$,`
M``!$C```PX_@`(,4,`"BCY`!O2=L@9F/)2!``.Q_OX_H?[Z/Y'^WC^!_MH_<
M?[6/V'^TC]1_LX_0?[*/S'^QC\A_L(\(`"`#\'^])Q"@H*[X@)F/)2@```GX
M(`,E(.`"*`"\CU[_0!`EH$``*(&9CP(`%B3N_P8D__\')!``MJ\)^"`#)2!`
M`/__$#PH`+R/"`"C)U"!`C3\?Q4F(1!#`(2!F8\&``8D(:A5`"4@@`()^"`#
M)2B@`E"!`C0(`*,G(1!#`"&`4`#\?P*2!0!`%"@`O(_]?P*20P`#)(0`0Q!!
M``,D*(&9CR4P```E.```$`"@KPGX(`,E((`"__\0/"@`O(]`@)F/H@81!/Q_
M%B8(`*,G):A``"@`O(]0@0(T(1!#``8``!`AL%8`1("9CR4HP`+#!A$$)2"@
M`B@`O(^$@9F/`(`&-"4HP`()^"`#)2"``B@`O(_T_T`<)3!```@`HR>(@)F/
M4($"-+Q_$"8A$$,`)2"``@GX(`,AH%``*`"\CR4HH`(E((`"2("9CRL'$004
M`!`F4($"-"@`O(\(`*,G(1!#`"2`AX\A@%``*``6)J!>]20``(*2)2```GR`
MF8___P8D`0`%)`(`$"80`**O"?@@`R4XH`(!`)0F]?_0%B@`O(\(`*4G)("'
MCU"!!#1\@)F/__\"/!0`LZ\A((4`$`"RK]!_0R0A$((`4($$-/__!B3X?T"@
M(2"%`"2`@H]D7^<D(1B#``$`!20L8$(D&`"CKR4@(`(<`**O"?@@`P`````H
M`+R/)(""CY`?0B0>_P`0-`"BK\/^`!```+>.)("6C___!3Q0@0(TY'ZE)"$0
M0P#47<0F)<B``G/W$00A*$4`</]`$"@`O(\``$*`;?]`$#```R1K_T,0`0`"
M),_^`!`0H**N!`"UCL3^H!(`@9F/"?@@`R4@H`($`$,LO_Y@%"@`O(\D@(6/
M_/]")(R!F8\A(*(""?@@`UQ?I20*N*("MOX`$"@`O(_^?P22?/^#%"B!F8__
M?P.2>O]B%"4P``!8`:.32``")'?_8A0E.```60&CDT4``B1S_V(4`````/__
M!R3&_P8D$`"VKPGX(`,E((`"*0`&)"@`O(\E**`"A(&9CPGX(`,E((`"__\&
M)"@`O(\!``4D)2`@`A@`M:\4`+.O$`"RKR2`@H\D@(>/?("9CRQ@0B1D7^<D
MKO\`$!P`HJ]0@9F/"?@@`P`````"`!P\6.2<)R'@F0/`_[TGD("9CS``LZ\D
M`+"O/`"_KQ``O*\T`+2O&`"T)R@`L:\X`+6O+`"RKV2!DX](@9"/``!BC@``
M!(X<`**O"?@@`P`````0`+R/)8A``)"`F8\)^"`#```$CB4H@`(0`+R/:``C
MDB2`D8\D@(2/:0!#H)`8,28ER"`""_<1!+A=A"0%`$`0$`"\CP``1(`Q``,D
MCP"#$`````!,@)F/R/H1!``````0`+R/D("9CPGX(`,```2.`P`')!``O(\!
M``8D)2!``"2`A8\4@9F/"?@@`YA?I200`+R/$@!`$"600`"0@)F/"?@@`P``
M!(X0`+R/)2!``!``0XXD@(:/-(&9CP``98P)^"`#G%_&)!``0HX``$*,"`!"
MC(`%0GQ^`$`4$`"\CY"`F8\)^"`#```$C@,`!R00`+R/`0`&)"4@0``D@(6/
M%(&9CPGX(`.D7Z4D$`"\CQ4`0!`ED$``)("$CR7((`(E*(`"S_81!'1=A"00
M`+R/):A`````!(Y9`$`0D("9CPGX(`,`````)3"@`A``O(\E($``$`!#CC2!
MF8\)^"`#``!EC!``O(^0@)F/*("5CPGX(`,```2.$`"\CR600`"0@)F/"?@@
M`P``!(X!``8D$`"\CR4@0``D@(6/]("9CPGX(`.H7Z4D)2!``A``O(\E*$``
M)("&CS2!F8\)^"`#P%_&)!``O(^0@)F/"?@@`P``!(XE*(`"$`"\CR7((`)I
M`$"@)("$CY[V$01H780D$`"\CR6`0``8`$`0Y+&BKN2`F8_``04D"?@@`R4@
M``(1``,D!0!#$!``O(\!`$,D`@!C+#8`8!`E.$``'`"CCP``8HXZ`&(4/`"_
MCS@`M8\T`+2/,`"SCRP`LH\H`+&/)`"PCP@`X`-``+TG*(""CU"`F8^$_!$$
MZ+%$C!``O(\E@$``XO]`%.2QHJXD@(2/\("9CPGX(`/(7X0D`0!"@'3_0!!,
M@)F/;_\`$``````)^"`#`````!``O(\0`$..*(""CR2`F8\``&2,Z+%"C"@>
M.2?-]Q$$``!%C*;_`!`0`+R/D("9CPGX(`,```2.$`"\CR4@0``0`$..T("9
MCPGX(`,``&6,>?\`$!``O(\H@(*/)("$CR4P``+P@)F/Z+%"C.Q?A"0)^"`#
M``!%C%"!F8\)^"`#``````(`'#S8X)PG(>"9`\C_O2<P`+.O*`"QKR6(@``0
M`+RO-`"_KRP`LJ\D`+"O9(&3CP``8HX<`**O)P"`$````````(*`)`!`$"2`
MF8_,'#DG2/<1!``````0`+R/``!#@`<`8!`E@$```0!")"\`8S@*@$,```!#
M@/S_8!0!`$(D*("2C___`R00H$*.&`!#$"2`A(\&`$`0``````0`(!(`````
M```B@A\`0!0D@(6/'`"CCP``8HXQ`&(4-`"_CS``LX\L`+*/*`"QCR0`L(\(
M`.`#.`"])R2`A(]L@9F/"?@@`PQ=A"3<_P`0$`"\CQ@`I2<D@)F/D!@Y)P[V
M$034780D'`!`$!``O(\``$*`&0!`$#```R07`$,0`0`")-[_`!`0H$*N!``&
M))R`F8\E(``""?@@`[1>I23<_T`4$`"\CQP`HX\``&*.#`!B%"2`F8\E("`"
M-`"_CS``LX\L`+*/\!DY)R@`L8\D`+"/2?8`$#@`O2?-_P`0$*!`KE"!F8\)
M^"`#``````````````````````(`'#Q`WYPG(>"9`U#]O2=D@8J/.`"()!@`
MHB<0`+RO>`"-)*P"OZ__``P\J`*RKR4P0`"D`K&OH`*PKP``0XV<`J.O!``%
MC0@`""40`,8D]/_`K/S_P*P"&@4`^/\'C0)>!0``3@4``/]C,*`X!WP`*@4`
M)1AK``(\)P`E&&D`)"BL`/#_QZPE&&4`[?^H%?C_PZP``DLD:`!)C`@`0B1\
M`$"L.`!#C#P`18QD`$B,"`!'C"9((P$,`$:,)D`%`?C_0XS\_T6,)CCI`"8P
MR``F&&<`)BBF`$`H!0#"-P,`0!@#`"4HI@`E&&4`ZO]+%'@`0ZR"6@(\``"'
MC`0`C8P8`+B/F7E")`@`BXS"-@<`(`",C$`9#0`,`(6,(<`"`Q``B(Q`>0<`
M&`")C"489@`AP`P#!`"`K()P"P`,`("L@"\%`!0`@*R`-PL`'`"`K"5XXP$F
M&`D!(7CX`24HK@`D&&L`)7#%`"``I8\F&&D`(1CC`8+`!P`F>`X!@#<-`"1H
MYP&`?P<`(2BB`"4PV``EP.8!*`"FCR$HJ0#"A@,`0,D#`"9HJ`$A**T`(3#"
M`"5H,`,F>-@!(2BM`"$PR``D>.,!@H@#`(!O`P`F&.X!PH8%`$#)!0`A&,,`
M,`"FCR5HL0$E>#`#(1AO`"$PP@`F>`T#)'CE`2$PS@""B`4`@'<%`"8H^`$X
M`*^/PH8#`$#)`P`A*,4`)7#1`24P,`,A>.(!(2BF`"8PK@$A>/@!),##`(*(
M`P"`-P,`)A@-`R$8XP%``*^/PH8%`$#)!0`E,-$`)<`P`R%XX@$A&'@`)L#&
M`2%H[0&"B`4`@'\%`"3`!0,F*`X#(2BE`25H\0%(`*^/PH8#`$#)`P`A>.(!
M)<`P`R$HN``FP,T`(7#N`8*(`P"`?P,`),`#`R88!@,A&,,!)7#Q`5``KX_"
MA@4`0,D%`"%XX@$EP#`#(1AX`";`K@$A,.8!@H@%`(!_!0`DP`4#)B@-`R$H
MQ0`E,/$!6`"OC\*&`P!`R0,`(7CB`27`,`,A*+@`)L#&`2%H[0&"B`,`@'\#
M`"3``P,F&`X#(1BC`25H\0%@`*^/PH8%`$#)!0`A>.(!)<`P`R$8>``FP,T`
M(7#N`8*(!0"`?P4`),`%`R8H!@,A*,4!)7#Q`6@`KX_"A@,`0,D#`"%XX@$E
MP#`#(2BX`";`K@$A,.8!@H@#`(!_`P`DP`,#)A@-`R$8PP`E,/$!<`"OC\*&
M!0!`R04`(7CB`27`,`,A&'@`)L#&`2%H[0&"B`4`@'\%`"3`!0,F*`X#(2BE
M`25H\0%X`*^/PH8#`$#)`P`A>.(!)<`P`R$HN``FP,T`(7#N`8*(`P"`?P,`
M),`#`R88!@,A&,,!)7#Q`8``KX_"A@4`0,D%`"%XX@$EP#`#(1AX`";`K@$A
M,.8!@H@%`(!_!0`DP`4#)B@-`R$HQ0`E,/$!B`"OC\*&`P!`R0,`(7CB`27`
M,`,A*+@`)L#&`2%H[0&"B`,`@'\#`"3``P,F&`X#(1BC`25H\0&0`*^/PH8%
M`$#)!0`A>.(!)<`P`R$8>``FP,T`(7#N`23`!0."B`4`@'\%`"8H!@,A*,4!
MF`"NC\*&`P!`R0,`)7CQ`27`,`,A<,(!(2BX`";`KP$A,,8!)'`#`X*(`P"`
MQP,`)AC-`2$8PP"@`*:/PH8%`$#)!0`EP!$#)7`P`R$PP@`A&&X`)G#X`2%H
MS0`D,,4!@G`%`(`O!0#"A@,`)7"N`*@`I8]`R0,`)C#/`"%HI@$A**(`)3`P
M`R%HI@$F,`X#(7BO`"0HPP"",`,`@!\#`"8HN``A>.4!)2AF`+``IH_"A@T`
M0,D-`"$PP@`F&,4!(3#8`"08;0`E$#`#)AAN`"%XX@$A,,,`N`"CC]EN`CR"
MR`T`H>M"-(!O#0`A&&(`)6BY`2$8;@`F<*T`)G#/`2$8;@#``*Z/PH8/`$#!
M#P""R`\`@'\/`"%PP@$EP!`#(3#8`"5X^0$A*,4!)G"O`29PQ@'"A@8`@L@&
M`$#!!@`A**X`@'<&`,@`IH\EP!`#(1AX`"$PP@`E<-D!(3#-`"9H[@$F:*,!
MPH8#`(+(`P!`P0,`(3#-`(!O`P#0`*./)<`0`R$HN``A&&(`)6BY`2$8;P`F
M>,T!)GCE`<*&!0""R`4`0,$%`"$8;P"`?P4`V`"ECR7`$`,A,-@`(2BB`"5X
M^0$A**X`)G"O`29PQ@'"A@8`@L@&`$#!!@`A**X`@'<&`.``IH\EP!`#(1AX
M`"$PP@`E<-D!(3#-`"9H[@$F:*,!PH8#`(+(`P!`P0,`(3#-`(!O`P#H`*./
M)<`0`R$HN``A&&(`)6BY`2$8;P`F>,T!)GCE`<*&!0""R`4`0,$%`"$8;P"`
M?P4`\`"ECR7`$`,A,-@`(2BB`"5X^0$A**X`)G"O`29PQ@'"A@8`@L@&`$#!
M!@`A**X`@'<&`/@`IH\EP!`#(1AX`"$PP@`E<-D!(3#-`"9H[@$F:*,!PH8#
M`(+(`P!`P0,`(3#-`(!O`P```:./)<`0`R$HN``A&&(`)6BY`2$8;P`F>,T!
M)GCE`<*&!0""R`4`0,$%`"$8;P"`?P4`"`&ECR7`$`,A,-@`(2BB`"5X^0$A
M**X`)G"O`29PQ@'"A@8`@L@&`$#!!@`A**X`@'<&`!`!IH\EP!`#(1AX`"$P
MP@`E<-D!(3#-`"9H[@$F:*,!PH8#`(+(`P!`P0,`(3#-`(!O`P`8`:./)<`0
M`R$HN``A&&(`)6BY`2$8;P`F>,T!)GCE`<*&!0""R`4`0,$%`"$8;P"`?P4`
M(`&ECR7`$`,A,-@`(2BB`"5X^0'"A@8`0,$&`"$HK@`F<*\!)G#&`8+(!@`E
MP!`#(2BN`(!W!@`H`::/(1AX`"5PV0'"A@,`0,$#`"$PP@`EP!`#(3#-`"9H
M[@$A*+@`)FBC`8+(`P`A,,T`@&\#`#`!HX_"A@4`0,$%`"$88@`EP!`#(3#8
M`"7`N0$A&&\`)GC8`29XY0&"R`4`(1AO`(!_!0`X`:6/PH8&`$!I!@`A**(`
M)7CY`25HL`$A&&T`(2BN`"9H#P,F:*8!(2BM`$`!K8_"A@,`0'$#`(+(!@"`
M-P8`)7#0`2%HH@$A**X`)7#9`"8P[@$A:+@!)C##`"%HI@&"P`,`@#<#`$@!
MHX_"A@4`0,D%`"$88@`EP-@`)<@P`R'(N0$A&&\`)FC8`29HI0$A&&T`4`&M
MC\*&&0!`,1D`@G@%`"%HH@&`+P4`)1#0`"4HKP`A:*X!@'\9`()P&0`A&&(`
M)A`%`R5X[@%8`:Z/)LA9`!N/`CS"A@,`0#$#`-R\0C0A:+D!)3#0`"%PP@$A
M:*8!)3"O`"20KP`A<-@!),##`(*(`P"`-P,`)1@2`V`!N(_"A@T`0,D-`"$8
MPP$E,-$`)7`P`R'``@,A&&X`)7#F`220Y@$AP`4#)'#-`25PT@$A<-@!:`&X
MC\*&`P!`R0,`@H@-`(`O#0`AP`(#)2BQ`"5H,`,A<,T!)6C%`"%X#P,D:*,!
M@L`#`(`?`P`DB,4`)1AX`'`!N(_"A@X`0,D.`"5HL0$A:*\!(<`"`R5X,`,A
M:*\!)7BC`"20HP`AP`8#)'CN`8*(#@"`-PX`)7#R`2%PV`%X`;B/PH8-`$#)
M#0`E,-$`)7@P`R'``@,A<,\!)7AF`"209@`AP`4#)'CM`8*(#0"`+PT`)6CR
M`2%HN`&``;B/PH8.`$#)#@`E*+$`)7@P`R'``@,A:*\!)7C%`"20Q0`AP`,#
M)'CN`8*(#@"`'PX`)7#R`2%PV`&(`;B/PH8-`$#)#0`E&'$`)7@P`R'``@,A
M<,\!)7BC`"20HP`AP`8#)'CM`8*(#0"`-PT`)6CR`2%HN`&0`;B/PH8.`$#)
M#@`E,-$`)7@P`R'``@,A:*\!)7AF`"209@`AP`4#)'CN`8*(#@"`+PX`)7#R
M`2%PV`&8`;B/PH8-`$#)#0`E*+$`)7@P`R'``@,A<,\!)7C%`"20Q0`AP`,#
M)'CM`8*(#0"`'PT`)6CR`2%HN`&@`;B/PH8.`$#)#@`E&'$`)7@P`R'``@,A
M:*\!)7BC`"20HP`AP`8#)'CN`8*(#@"`-PX`)7#R`2%PV`&H`;B/PH8-`$#)
M#0`E,-$`)7@P`R'``@,A<,\!)7AF`"209@`AP`4#)'CM`8*(#0"`+PT`)6CR
M`2%HN`&P`;B/PH8.`$#)#@`E*+$`)7@P`R'``@,A:*\!)7C%`"20Q0`AP`,#
M)'CN`8*(#@"`'PX`)7#R`2%PV`&X`;B/PH8-`$#)#0`E&'$`)7@P`R'``@,A
M<,\!)7BC`"20HP`AP`8#)'CM`8*(#0"`-PT`)6CR`2%HN`'``;B/PH8.`$#)
M#@`E,-$`)7@P`R'``@,A:*\!)7AF`"209@`AP`4#)'CN`8*(#@"`+PX`)7#R
M`2%PV`'(`;B/PH8-`$#)#0`E*+$`)7@P`R'``@,A<,\!)7C%`"20Q0`AP`,#
M)'CM`8*(#0"`'PT`)6CR`2%HN`'0`;B/PH8.`$#)#@`E&'$`)7@P`R'``@,A
M:*\!)7BC`"20HP`AP`8#)'CN`8*(#@"`-PX`)7#R`<*&#0!`R0T`(7#8`=@!
MN(\E,-$`)7@P`R%PSP$AP`(#)7AF`"209@`D>.T!(<`%`X*(#0"`+PT`)6CR
M`>`!KX_"A@X`0,D.`"%HN`$E*+$`)<`P`R%XX@$A:+@!)<#%`"%XXP&"B`X`
M))#%`(`?#@`DP`X#Z`&NC\*&#0!`R0T`)<`2`R'`#P,E&'$`)7@P`R%PP@$A
MP`\#)7BC`"$PQ@$DB*,`)'CM`25X\0$A>.8!\`&FC\+.&`!`<1@`@H`-`(!O
M#0`A$,(`)6BP`24PV0$A>.8!)3!M`"$H10`D,-@`)!!M`"4PP@`A,,4`^`&E
MCV+*`CR"R!@`UL%"-(#'&``A**(`)<`9`\*&#P!`<0\`(2BC`"88N`$E<-`!
M)AAO`"$PS@`A**,```*CC\*&!@""R`\`0'$&`(!_#P`A&&(`)7CY`25PT`$A
M**X`(1AM`"9P#P,F<,8!@L@&`"$8;@"`=P8`"`*FC\*&!0!`:04`(3#"`"5P
MV0$E:+`!(1AM`"$PV``F:.X!)FBE`8+(!0`A,,T`@&\%`!`"I8_"A@,`)6BY
M`2$HH@""R`,`(2BO`"9XS0$F>.,!0,$#`"$HKP"`?P,`&`*CCR7`$`,A,-@`
M(1AB`"5X^0$A&&X`)G"O`29PQ@'"A@8`@L@&`$#!!@`A&&X`@'<&`"`"IH\E
MP!`#(2BX`"$PP@`E<-D!(3#-`"9H[@$F:*4!PH8%`(+(!0!`P04`(3#-`(!O
M!0`H`J6/)<`0`R$8>``A**(`)6BY`2$HKP`F>,T!)GCC`<*&`P""R`,`0,$#
M`"$HKP"`?P,`,`*CCR7`$`,A,-@`(1AB`"5X^0$A&&X`)G"O`29PQ@'"A@8`
M@L@&`$#!!@`A&&X`@'<&`#@"IH\EP!`#(2BX`"$PP@`E<-D!(3#-`"9H[@$F
M:*4!PH8%`(+(!0!`P04`(3#-`(!O!0!``J6/)<`0`R$8>``A**(`)6BY`2$H
MKP`F>,T!)GCC`<*&`P""R`,`0,$#`"$HKP"`?P,`2`*CCR7`$`,A,-@`(1AB
M`"5X^0$A&&X`)G"O`29PQ@'"A@8`@L@&`$#!!@`A&&X`@'<&`%`"IH\EP!`#
M(2BX`"$PP@`E<-D!(3#-`"9H[@$F:*4!PH8%`(+(!0!`P04`(3#-`(!O!0!8
M`J6/)<`0`R$8>``A**(`)6BY`2$HKP`F>,T!)GCC`<*&`P""R`,`0,$#`"$H
MKP"`?P,`8`*CCR7`$`,A,-@`(1AB`"5X^0'"A@8`0,$&`"$8;@`F<*\!)G#&
M`8+(!@`EP!`#(1AN`(!W!@!H`J:/(2BX`"5PV0'"A@4`0,$%`"$PP@`EP!`#
M(3#-`"9H[@$A&'@`)FBE`8+(!0`A,,T`@&\%`'`"I8_"A@,`0,$#`"$HH@`E
MP!`#(3#8`"7`N0$A**\`)GC8`29XXP&"R`,`(2BO`(!_`P!X`J./PH8&`$!I
M!@`A&&(`)7CY`25HL`$A**T`(1AN`"9H#P,F:*8!(1AM`(`"K8_"A@4`0'$%
M`(+(!@"`-P8`)7#0`2%HH@$A&&X`)7#9`"8P[@$A:+@!)C#%`,*&`P`A:*8!
MB`*FCT#!`P""R`4`)<`0`X`O!0`AP+@!D`*MCR$PP@`E*+D`)LC%`2$PSP`A
M:*(!0'D8`"80(P/"AA@`@L@#`"$0P@"`'P,`(3"G`24X\`$A$$<`)1AY`"$P
MS@`F<*,`PLX"`$!I`@"">!@`@#\8`";`V`$A,-@`)6BY`24X[P`A$$L`(1AI
M`"$PS0`(`(*L(4#H`!@`@ZPA**P```"&K!``B*P@`(6L)`"`K)P"HX\``$*-
M!@!B%*P"OX^H`K*/I`*QCZ`"L(\(`.`#L`*])U"!F8\)^"`#``````(`'#Q<
MS)PG(>"9`^#_O2<8@9F/'`"_KQ``O*\)^"`#@``$)$5G!#PE*```>`!`K`$C
MA#0``$2LS>\$/`0`1:PE*```B:N$-`@`1*RZF`0\#`!%K"4H``#^W(0T$`!$
MK#(0!#P4`$6L)2@``'94A#08`$2LTL,$/!P`1:PE,```)3@``"4H```H`$:L
M\.&$-"P`1ZP@`$2L)`!%K#``1JPT`$>L'`"_CP@`X`,@`+TG`@`</*S+G"<A
MX)D#R/^])S``MJ\EL(``+`"UKR6HP``8`+"OP#`&`!``O*\E@*``-`"_KR@`
MM*\D`+.O(`"RKQP`L:\H`(>,+`""C#``@XPT`(B,(3#'`$H`0!3#)Q4`*SC'
M`$@`X!0!`&(DP#@$`'@`Q8Y"%Q4`*`#&KD(G!``L`,"N)1#B`"$80P`A((@`
M*Q!B`#``PZXA$$0`.`#4)CT`H!0T`,*N0`"B*E$`0!0D@)./P/^U)H*)%0#P
M0',F`0`R)H"1$@`AD!("0``$)B4H``(E$(`"`P"HB`<`IX@+`*:(#P"CB```
MJ)@$`*>8"`"FF`P`HY@0`*4D`P!(J```2+@'`$>H!`!'N`L`1J@(`$:X#P!#
MJ`P`0[CN_Z04$`!")"4@P`(ER&`"S_H1!"6`H`#E_Q(6$`"\CX")$0`CJ+$"
M:(&9CR4PH`(E*$`""?@@`R4@@`)X`-6N-`"_CS``MH\L`+6/*`"TCR0`LX\@
M`+*/'`"QCQ@`L(\(`.`#.`"])P$`8B0K&$,`(4!H`+;_`!`E&$``0``2)&B!
MF8\A((4"(XA%`B4H``(J$#4""HBB`@GX(`,E,"`">`#"CA``O(\A$"("Y/]2
M%'@`PJXD@)./)2#``B.HL0+P0',F)<A@`J'Z$00A@!$"KO\`$!``O(_3_P`0
M)9```@(`'#RPR9PG(>"9`\C_O2?H@)F/,`"UKS@`M20@`+&O)8B``!P`L*^`
M_P0D$`"\KR6`H``T`+^O+`"TKR@`LZ\D`+*O*`"RC#``LXS`*$)^H)@3?`$`
M0R0A$*("H)`2?#D`92@``$2@`I0R``*<,P!/`*`4(2"C`D``!B0E*```"?@@
M`R,PPP`0`+R/)("4C_!`E"8ER(`"=?H1!"4@``(X``8D$`"\CR4H``#H@)F/
M"?@@`R4@H`(E(``"<``3KB7(@`)J^A$$=``2KB4@``(#``*2$`"\CP``(J("
M``*6<(&9CP$`(J(```*.`A("``(`(J(```*.`P`BH@L``I($`"*B"@`"E@4`
M(J((``*.`A("``8`(J((``*.!P`BHA,``I((`"*B$@`"E@D`(J(0``*.`A("
M``H`(J(0``*."P`BHAL``I(,`"*B&@`"E@T`(J(8``*.`A("``X`(J(8``*.
M#P`BHB,``I(0`"*B(@`"EA$`(J(@``*.`A("`!(`(J(@``*.$P`BHC0`OX\P
M`+6/+`"TCR@`LX\D`+*/(`"QCQP`L(\(`"`#.`"])S@`!B0E*```"?@@`R,P
MPP`0`+R/)("4C[O_`!#P0)0F`@`</.#'G"<AX)D#R/^])VB`F8\0`+RO,`"U
MKR6HP``L`+2O):"@`"@`LZ\EF(``)`"RKQP`L*\T`+^OU.X1!"``L:\0`+R/
M;("0CW"`DH\CD%`"@Y`2``D`0!(EB``````9C@$`,28E,*`")2B``@GX(`,E
M(&`"^?]1%@0`$"8T`+^/,`"UCRP`M(\H`+./)`"RCR``L8\<`+"/"`#@`S@`
MO2<(`.`#```````````"`!P\,,><)R'@F0-D@(*/+(&9CP@`(`,``$>,````
M`!"`F8\E>.`#"?@@`VD`&"00@)F/)7C@`PGX(`-H`!@D$("9CR5XX`,)^"`#
M9@`8)!"`F8\E>.`#"?@@`V0`&"00@)F/)7C@`PGX(`-B`!@D$("9CR5XX`,)
M^"`#80`8)!"`F8\E>.`#"?@@`V``&"00@)F/)7C@`PGX(`-?`!@D$("9CR5X
MX`,)^"`#7``8)!"`F8\E>.`#"?@@`UL`&"00@)F/)7C@`PGX(`-:`!@D$("9
MCR5XX`,)^"`#60`8)!"`F8\E>.`#"?@@`U@`&"00@)F/)7C@`PGX(`-6`!@D
M$("9CR5XX`,)^"`#50`8)!"`F8\E>.`#"?@@`U,`&"00@)F/)7C@`PGX(`-2
M`!@D$("9CR5XX`,)^"`#40`8)!"`F8\E>.`#"?@@`U``&"00@)F/)7C@`PGX
M(`-/`!@D$("9CR5XX`,)^"`#3@`8)!"`F8\E>.`#"?@@`TT`&"00@)F/)7C@
M`PGX(`-,`!@D$("9CR5XX`,)^"`#2P`8)!"`F8\E>.`#"?@@`TH`&"00@)F/
M)7C@`PGX(`-(`!@D$("9CR5XX`,)^"`#1P`8)!"`F8\E>.`#"?@@`T8`&"00
M@)F/)7C@`PGX(`-%`!@D$("9CR5XX`,)^"`#1``8)!"`F8\E>.`#"?@@`T,`
M&"00@)F/)7C@`PGX(`-"`!@D$("9CR5XX`,)^"`#00`8)!"`F8\E>.`#"?@@
M`T``&"00@)F/)7C@`PGX(`,_`!@D$("9CR5XX`,)^"`#/@`8)!"`F8\E>.`#
M"?@@`SP`&"00@)F/)7C@`PGX(`,[`!@D$("9CR5XX`,)^"`#.@`8)!"`F8\E
M>.`#"?@@`SD`&"00@)F/)7C@`PGX(`,X`!@D$("9CR5XX`,)^"`#-P`8)!"`
MF8\E>.`#"?@@`S8`&"00@)F/)7C@`PGX(`,U`!@D$("9CR5XX`,)^"`#-``8
M)!"`F8\E>.`#"?@@`S,`&"00@)F/)7C@`PGX(`,Q`!@D$("9CR5XX`,)^"`#
M,``8)!"`F8\E>.`#"?@@`R\`&"00@)F/)7C@`PGX(`,N`!@D$("9CR5XX`,)
M^"`#+``8)!"`F8\E>.`#"?@@`RH`&"00@)F/)7C@`PGX(`,I`!@D$("9CR5X
MX`,)^"`#*``8)!"`F8\E>.`#"?@@`R<`&"00@)F/)7C@`PGX(`,F`!@D$("9
MCR5XX`,)^"`#)0`8)!"`F8\E>.`#"?@@`R0`&"0`````````````````````
M`@`</&##G"<AX)D#X/^])Q``O*\<`+^O'`"_CP@`X`,@`+TG````````````
M`````0`"`"5S+R5S````+@```"\````O<')O8R]S96QF+V5X90``1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4````
M`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!344`````
M.@```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]05`````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M``!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'````
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$7TQ)
M0E)!4EE?4$%42`!54T52`````%-94U1%30``+W1M<`````!414U01$E2`%1-
M4`!54T523D%-10`````E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N
M<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I
M;VXI"@``4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,`
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P97)L
M`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U,@```%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M
M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`[
M"F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@
M/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D
M9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I
M8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S
M:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92![
M"B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D
M;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E
M860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#
M*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@
M,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`[
M"B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D
M(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E
M860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI
M;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE
M)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX[
M"B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N
M)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H
M+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R
M;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF
M;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA
M;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@
M)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I
M;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P
M87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET[
M"GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II
M<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z
M)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P
M87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L
M(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@
M9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A
M9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E
M="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S
M>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`
M:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z
M.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB
M7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD
M969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<
M12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S
M=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII
M9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L*
M*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]
M"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&
M24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I
M;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M
M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I
M("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA
M;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*
M:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI
M6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY
M("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4[
M"F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005([
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I
M;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/
M.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R
M8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O
M<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL
M960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J
M(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$[
M"FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ
M<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI.PHD;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O
M9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E
M96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A
M9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I
M9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P
M<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I
M9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;
M0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT
M96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI
M;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*
M?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!
M4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,
M14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L
M96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L
M=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````````
M``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I
M+F,`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!P&```!!@```````````````````````#_____````````````````.&``
M````````````````````````````````````````````````@"`4``!06```
M]%@```````````(````!`-@[``!<(P``)"\``(`D``#44P``A%0``(!6``"H
M)P``I#````!9```@H`$`6#\``#2@`0#$H0$`X!,``/B?`0#\GP$`````````
M``"P7```H%P``)!<``"`7```<%P``&!<``!07````````$!<````````,%P`
M`"!<```07````%P```````#P6P``X%L``-!;``#`6P``L%L``*!;``"06P``
M@%L``'!;``!@6P```````%!;``!`6P``,%L``"!;```06P```%L``/!:``#@
M6@``T%H``,!:``"P6@```````*!:``"06@``@%H``'!:``!@6@``4%H``$!:
M```P6@``(%H``!!:`````````%H``/!9````````X%D``-!9``#`60``L%D`
M`*!9`````````````)!9``"`60``<%D``&!9````````4%D```````!`60``
M`````#!9```@60``Q*$!`$=#0SH@*$1E8FEA;B`Q,"XR+C$M-BD@,3`N,BXQ
M(#(P,C$P,3$P``"0&`````!_@/S___\``````````#@````=````'P```/`9
M`````/^`_/___P``````````\````!T````?````%!P``````X#\____````
M``````#0````'0```!\```#,'``````#@/S___\``````````"@````=````
M'P```"@>`````#^`_/___P``````````0!```!T````?````D!\`````_X#\
M____``````````!(````'0```!\```!<(@`````!@/S___\``````````"@`
M```=````'P````@C``````"`_/___P``````````(````!T````?````7",`
M````!X#\____``````````!((```'0```!\```!H)```````````````````
M```````````=````'P```(`D`````/_`_/___P``````````"!$``!T````?
M````0"<`````````````````````````````'0```!\```!L)P``````````
M```````````````````=````'P```*@G`````/_`_/___P``````````<```
M`!T````?````+"X``````X#\____```````````P````'0```!\```#<+@``
M````@/S___\``````````"`````=````'P```"0O`````!^`_/___P``````
M````2````!T````?````I#``````_\#\____``````````"`@0``'0```!\`
M``#8.P`````_@/S___\``````````$`````=````'P```%@_``````^`_/__
M_P``````````.````!T````?````(!0`````/X#\____``````````!0````
M'0```!\```#P0``````'@/S___\``````````+`"```=````'P```-13````
M``"`_/___P``````````(````!T````?````A%0`````?X#\____````````
M```X````'0```!\```"`5@`````_@/S___\``````````#@````=````'P``
M`%!8`````#^`_/___P``````````.````!T````?````]%@`````````````
M````````````````'0```!\`````60`````````````````````````````=
M````'P```$$/````9VYU``$'````!`4`+G-H<W1R=&%B`"YI;G1E<G``+DU)
M4%,N86)I9FQA9W,`+G)E9VEN9F\`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E
M+D%"22UT86<`+F1Y;F%M:6,`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N
M=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N:6YI=``N=&5X=``N
M34E04RYS='5B<P`N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A
M>0`N9FEN:5]A<G)A>0`N9&%T80`N<FQD7VUA<``N9V]T`"YS9&%T80`N8G-S
M`"YC;VUM96YT`"YP9'(`+F=N=2YA='1R:6)U=&5S`"YM9&5B=6<N86)I,S(`
M``````````````````````````````````````````````````````L````!
M`````@```)0!``"4`0``#0```````````````0`````````3````*@``<`(`
M``"H`0``J`$``!@```````````````@````8````(@````8``'`"````P`$`
M`,`!```8```````````````$````&````"L````'`````@```-@!``#8`0``
M)```````````````!``````````^````!P````(```#\`0``_`$``"``````
M``````````0`````````3`````8````"````'`(``!P"```X`0``"0``````
M```$````"````%4````%`````@```%0#``!4`P``-`,```@`````````!```
M``0```!;````"P````(```"(!@``B`8``*`&```)`````@````0````0````
M8P````,````"````*`T``"@-```)!0`````````````!`````````&L```#_
M__]O`@```#(2```R$@``U`````@``````````@````(```!X````_O__;P(`
M```($P``"!,``+`````)`````P````0`````````AP````D````"````N!,`
M`+@3```H````"``````````$````"````)`````!````!@```.`3``#@$P``
M/```````````````!`````````"6`````0````8````@%```(!0```!%````
M`````````!``````````G`````$````&````(%D``"!9``"P`P``````````
M```$`````````*@````!````!@```-!<``#07```)```````````````!```
M``````"N`````0````(`````70```%T``/`^`````````````!``````````
MM@````$````"````\)L``/";```$```````````````$`````````,`````.
M`````P```/B?`0#XGP``!```````````````!`````0```#,````#P````,`
M``#\GP$`_)\```0```````````````0````$````V`````$````#`````*`!
M``"@```P```````````````0`````````-X````!`````P```#"@`0`PH```
M!```````````````!`````````#G`````0````,``!!`H`$`0*```(0!````
M`````````!`````$````[`````$````#```0Q*$!`,2A```$````````````
M```$`````````/,````(`````P```-"A`0#(H0``(!``````````````$```
M``````#X`````0```#``````````R*$``"<```````````````$````!````
M`0$```$``````````````/"A``"``P`````````````$``````````8!``#U
M__]O``````````!PI0``$````````````````0`````````6`0```0``````
M````````@*4```````````````````$``````````0````,`````````````
9`("E```D`0`````````````!````````````
